# Some commands

```bash
cmr "get aria2" --version=1.37.0
cmr "get aria2" --install
cmr "get aria2" --path={path to the directory with aria2}
cmr "get aria2" --input={full path to aria2}
cmr "get aria2" --shell
```
